@@ -40,7 +40,10 @@ logLik(m2_pf)
 ## i.e., cohort=0.
 ##
 
-## A call to igirf using the moment-based guide function can test compiled code for eunit_measure, munit_measure, vunit_measure, dunit_measure, runit_measure, rprocess, skeleton, rinit and partrans. 
+## A call to igirf using the moment-based guide function can test
+## compiled code for eunit_measure, munit_measure, vunit_measure,
+## dunit_measure, runit_measure, rprocess, skeleton, rinit and partrans. 
+## It also tests igirf (method=moment) with covariates
 
 m3_params <- m_params
 m3_params["cohort"] <- 0
@@ -50,20 +53,30 @@ m3_igirf_np <- 5
 m3_igirf_nguide <- 5
 m3_igirf_ngirf <- 2
 
-m3_igirf_out <- igirf(m_model, Ngirf = m3_igirf_ngirf,
-  params=m3_params,
-  rw.sd=rw_sd(g=0.02),
-  cooling.type = "geometric",
-  cooling.fraction.50 = 0.5,
-  Np=m3_igirf_np,
-  Ninter = m3_igirf_ninter,
-  lookahead = m3_igirf_lookahead,
-  Nguide = m3_igirf_nguide,
-  kind = 'moment',
-  verbose = FALSE
+suppressWarnings(
+  m3_igirf_out <- igirf(m_model, Ngirf = m3_igirf_ngirf,
+    params=m3_params,
+    rw.sd=rw_sd(g=0.02),
+    cooling.type = "geometric",
+    cooling.fraction.50 = 0.5,
+    Np=m3_igirf_np,
+    Ninter = m3_igirf_ninter,
+    lookahead = m3_igirf_lookahead,
+    Nguide = m3_igirf_nguide,
+    kind = 'moment',
+    verbose = FALSE
+  )
 )
 logLik(m3_igirf_out)
 
+## another call to igirf tests igirf (method=bootstrap) with covariates
+suppressWarnings(m3_igirf_bootstrap_out <- igirf(m3_igirf_out,kind='bootstrap'))
+logLik(m3_igirf_bootstrap_out)
+
+## test error message
+try(measles(U=1000))
+
+
 ## --------------------------------------------------------------------
 ## using measles to test spatPomp() covariate replacement functionality
 ## ____________________________________________________________________
